@@ -23,7 +23,7 @@
 #include "dact.h"
 #include "config.h"
 
-#if (defined(USE_MODULES) && !defined(AS_MODULE)) || !defined(HAVE_LIBLZO) || !defined(DEBUG) || !defined(HAVE_LIBLZO) || !defined(HAVE_LZO1Y_H)
+#if (defined(USE_MODULES) && !defined(AS_MODULE)) || !defined(HAVE_LIBLZO) || !defined(HAVE_LIBLZO) || !defined(HAVE_LZO1Y_H)
 #define comp_lzooy_algo DACT_FAILED_ALGO
 #else
 int comp_lzooy_algo(int mode, unsigned char *prev_block, unsigned char *curr_block, char *out_block, int blk_size);
