@@ -120,12 +120,12 @@ int load_module (char *modulename, const char *options) {
 		mbuf=mdircpy;
 		while ((tmpbuf=strsep(&mbuf, ":"))) {
 			snprintf(modulefile, sizeof(modulefile)-1, "%s/%s.so",tmpbuf,modulename);
-			if ((mh=dlopen(modulefile, RTLD_LAZY|RTLD_GLOBAL))!=NULL) break;
+			if ((mh=dlopen(modulefile, RTLD_GLOBAL|RTLD_LAZY))!=NULL) break;
 		}
 		free(mdircpy);
 	} else {
 		strncpy(modulefile, modulename, sizeof(modulefile)-1);
-		if ((mh=dlopen(modulefile, RTLD_LAZY|RTLD_GLOBAL))==NULL) {
+		if ((mh=dlopen(modulefile, RTLD_GLOBAL|RTLD_LAZY))==NULL) {
 			PRINTERR("Could not load module.");
 			return(DACT_MOD_FAIL);
 		}
